<?php

namespace app\controllers;

use app\models\ImagenFile;
use Imagine\Image\Box;
use Yii;
use app\models\Imagen;
use app\models\ImagenSearch;
use yii\filters\AccessControl;
use yii\imagine\Image;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;

/**
 * ImagenController implements the CRUD actions for Imagen model.
 */
class ImagenController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                'class'=>AccessControl::classname(),
                'rules'=>[
                    [
                        'allow'=>true,
                        'roles'=>['@']
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Imagen models.
     * @return mixed
     */
    public function actionIndex()
    {
        ini_set('memory_limit', '250M');
        $searchModel = new ImagenSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        $modelImagen = new ImagenFile();
        $model = new Imagen();

        $fechaHoy = date("Y-m-d H:i:s");

        if (  $model->load(Yii::$app->request->post()) ){

            $model->IdProyecto = Yii::$app->request->queryParams['id'];
            $model->CreadoPor = Yii::$app->user->id;
            $model->FechaCreacion = $fechaHoy;


            $modelImagen->imagen = UploadedFile::getInstance($modelImagen, 'imagen');
            if( $modelImagen->validate() && !empty( $modelImagen->imagen ) ) {

                //crea en la carpeta que se va almacenar
                $folder = "/proyecto/";
                if( !file_exists( Yii::getAlias("@webroot" . $folder) ) ){

                    if(!mkdir( Yii::getAlias("@webroot" . $folder) , 0777, true)) {
                        throw new \yii\web\NotFoundHttpException(" No se pudo Crear carpeta para la Imagen. ");
                    }
                }

                $model->save();

                $file = sha1( $model->IdProyecto . $fechaHoy );

                // foto grande
                Image::getImagine()->open($modelImagen->imagen->tempName)
                    ->thumbnail(new Box(800,800))->save(Yii::getAlias( "@webroot".$folder.$file.".jpg" ) );

                // Tumbail 150x150
                Image::getImagine()->open($modelImagen->imagen->tempName)
                    ->thumbnail(new Box(150,150))->save(Yii::getAlias( "@webroot".$folder.$file."_150x150.jpg" ) );


                $model->Filename = $folder.$file;
                $model->save();
                return $this->redirect(['index', 'id' => $model->IdProyecto ]);

            }
        }

        if( !empty( Yii::$app->request->queryParams['id'] ) ) $model->IdProyecto = Yii::$app->request->queryParams['id'];

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'modelImagen'=>$modelImagen,
            'model'=>$model,
        ]);
    }



    /**
     * Displays a single Imagen model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Imagen model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        /*
        $model = new Imagen();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->IdImagen]);
        } else {
            return $this->render('create', [
                'model' => $model,
            ]);
        }*/




    }

    /**
     * Updates an existing Imagen model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        /*
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->IdImagen]);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
        */
    }

    /**
     * Deletes an existing Imagen model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {

        $model = Imagen::findOne($id) ;

        if( !is_null($model ) ){
            if(strlen($model->Filename)>0){
                //$model->Filename;
                if( file_exists( Yii::getAlias("@webroot" . $model->Filename.".jpg") ) ){
                    unlink( Yii::getAlias('@webroot'). $model->Filename.".jpg" );
                }

                if( file_exists( Yii::getAlias("@webroot" . $model->Filename."_150x150.jpg") ) ){
                    unlink( Yii::getAlias('@webroot'). $model->Filename."_150x150.jpg" );
                }
            }

            $this->findModel($id)->delete();
        }



        return $this->redirect(['index',"id"=>$model->IdProyecto ]);
    }

    public function actionTest(){
        echo "hola mundo";
    }

    /**
     * Finds the Imagen model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Imagen the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Imagen::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
