<?php

namespace app\controllers;

use app\commands\Clasificadores\TipoClasificador;
use app\commands\Roles;
use app\models\Clasificadorcomun;
use app\models\Empresa;
use app\models\ImagenFile;
use app\models\Proyectodetalle;
use Imagine\Image\Box;
use Yii;
use app\models\Proyecto;
use app\models\ProyectoSearch;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\imagine\Image;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;

/**
 * ProyectoController implements the CRUD actions for Proyecto model.
 */
class ProyectoController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                    'class'=>AccessControl::classname(),
                    'rules'=>[
                            [
                                    'allow'=>true,
                                    'roles'=>['@']
                            ],
                    ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    public function beforeAction($event)
    {
        if(!Yii::$app->user->isGuest){
            if(Yii::$app->user->identity->Rol!=Roles::Administrador && Yii::$app->user->identity->Rol!=Roles::Registrador){
                return $this->redirect(['site/index']);
            }
        }
        return parent::beforeAction($event);
    }

    /**
     * Lists all Proyecto models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new ProyectoSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        /*
               $comboTipoProyecto = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>TipoClasificador::TipoProyecto])->all();
               $comboTipoProyecto = ArrayHelper::map($comboTipoProyecto, 'IdClasificadorComun','Nomb);

               /*
               $comboEmpresas = Empresa::find()->where(["Activo"=>1])->all();
               $comboEmpresas = ArrayHelper::map($comboEmpresas, 'IdEmpresa','RazonSocial' );
               */

        return $this->render('index', [
                'searchModel' => $searchModel,
                'dataProvider' => $dataProvider,
                //'comboTipoProyecto' => $comboTipoProyecto,
        ]);
    }

    /**
     * Displays a single Proyecto model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Proyecto model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Proyecto();

        if ($model->load(Yii::$app->request->post()) ) {

            $model->FechaCreacion = date("Y-m-d H:i:s");
            $model->IdCreadoPor = Yii::$app->user->id;
            $model->save();

            return $this->redirect(['view', 'id' => $model->IdProyecto]);


        } else {

            $comboTipoProyecto = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>TipoClasificador::TipoProyecto])->all();
            $comboTipoProyecto = ArrayHelper::map($comboTipoProyecto, 'IdClasificadorComun','Nombre');

            $comboEstadoProyecto = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>TipoClasificador::EstadoProyecto])->all();
            $comboEstadoProyecto = ArrayHelper::map($comboEstadoProyecto, 'IdClasificadorComun','Nombre');

            $comboEmpresas = Empresa::find()->where(["Activo"=>1])->all();
            $comboEmpresas = ArrayHelper::map($comboEmpresas, 'IdEmpresa','RazonSocial' );

            return $this->render('create', [
                'model' => $model,
                'comboTipoProyecto' => $comboTipoProyecto,
                'comboEmpresas' => $comboEmpresas,
                'comboEstadoProyecto'=>$comboEstadoProyecto,
            ]);
        }
    }

    /**
     * Updates an existing Proyecto model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        date_default_timezone_set('America/La_Paz');
        $model = $this->findModel($id);

        $modelImagen = new ImagenFile();
        if ( $model->load(Yii::$app->request->post()) ) {

            $fechaModificacion =  date("Y-m-d H:i:s");
            $modelImagen->load( Yii::$app->request->post()  );
            $modelImagen->imagen = UploadedFile::getInstance($modelImagen, 'imagen');
            if( $modelImagen->validate() && !empty( $modelImagen->imagen ) ) {

                //crea en la carpeta que se va almacenar
                $folder = "/proyecto/";
                if( !file_exists( Yii::getAlias("@webroot" . $folder) ) ){

                    if(!mkdir( Yii::getAlias("@webroot" . $folder) , 0777, true)) {
                        throw new \yii\web\NotFoundHttpException(" No se pudo Crear carpeta para la Imagen. ");
                    }
                }

                $file = sha1( $model->IdProyecto + $fechaModificacion ).".jpg";

                Image::getImagine()->open($modelImagen->imagen->tempName)
                    ->thumbnail(new Box(600,600))->save(Yii::getAlias( "@webroot".$folder.$file ) );

                $model->Imagen = $folder.$file;


            }


            $model->IdModificadoPor = Yii::$app->user->id;
            $model->FechaModificacion = $fechaModificacion;
            $model->save();
            return $this->redirect(['view', 'id' => $model->IdProyecto]);
            //return $this->redirect(['index']);

        } else {

            return $this->render('update', [
                    'model' => $model,
                    'modelImagen'=>$modelImagen,
            ]);

        }
    }

    /**
     * Deletes an existing Proyecto model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Proyecto model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Proyecto the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Proyecto::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
