<?php
App::uses('AppController', 'Controller');
App::import('Model', 'User');
/**
 * Mensajes Controller
 *
 * @property Mensaje $Mensaje
 * @property PaginatorComponent $Paginator
 */
class MensajesController extends AppController {

/**
 * Components
 *
 * @var array
 */
	public $components = array('Paginator');
	public $uses=array('Mensaje','Anuncio','InfoContacto','Tipo','Categoria','Ciudad','Zona');
/**
 * index method
 *
 * @return void
 */
	public function index() {
		$this->Mensaje->recursive = 0;
		$this->set('mensajes', $this->Paginator->paginate());
	}

/**
 * view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function view($id = null) {
		if (!$this->Mensaje->exists($id)) {
			throw new NotFoundException(__('Invalid mensaje'));
		}
		$options = array('conditions' => array('Mensaje.' . $this->Mensaje->primaryKey => $id));
		$this->set('mensaje', $this->Mensaje->find('first', $options));
	}

/**
 * add method
 *
 * @return void
 */
	public function add() {
		if ($this->request->is('post')) {
			$this->Mensaje->create();
			if ($this->Mensaje->save($this->request->data)) {
				$this->Session->setFlash(__('The mensaje has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The mensaje could not be saved. Please, try again.'));
			}
		}
		$tipos = $this->Mensaje->Tipo->find('list');
		$categorias = $this->Mensaje->Categorium->find('list');
		$zonas = $this->Mensaje->Zona->find('list');
		$ciudads = $this->Mensaje->Ciudad->find('list');
		$this->set(compact('tipos', 'categorias', 'zonas', 'ciudads'));
	}

/**
 * edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function edit($id = null) {
		if (!$this->Mensaje->exists($id)) {
			throw new NotFoundException(__('Invalid mensaje'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->Mensaje->save($this->request->data)) {
				$this->Session->setFlash(__('The mensaje has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The mensaje could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('Mensaje.' . $this->Mensaje->primaryKey => $id));
			$this->request->data = $this->Mensaje->find('first', $options);
		}
		$tipos = $this->Mensaje->Tipo->find('list');
		$categorias = $this->Mensaje->Categorium->find('list');
		$zonas = $this->Mensaje->Zona->find('list');
		$ciudads = $this->Mensaje->Ciudad->find('list');
		$this->set(compact('tipos', 'categorias', 'zonas', 'ciudads'));
	}

/**
 * delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function delete($id = null) {
		$this->Mensaje->id = $id;
		if (!$this->Mensaje->exists()) {
			throw new NotFoundException(__('Invalid mensaje'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->Mensaje->delete()) {
			$this->Session->setFlash(__('The mensaje has been deleted.'));
		} else {
			$this->Session->setFlash(__('The mensaje could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}

/**
 * admin_index method
 *
 * @return void
 */
	public function admin_index() {
		$this->Mensaje->recursive = 0;
		$this->paginate = array('limit' => 15, 'order' => array('Mensaje.id' => 'desc')); //ordenar anuncio por un campo
		$this->set('mensajes', $this->Paginator->paginate());
		$this->layout='bootsolicitud';
	}

/**
 * admin_view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_view($id = null) {
		if (!$this->Mensaje->exists($id)) {
			throw new NotFoundException(__('Invalid mensaje'));
		}
		$options = array('conditions' => array('Mensaje.' . $this->Mensaje->primaryKey => $id));
		$this->set('mensaje', $this->Mensaje->find('first', $options));
		$this->layout='bootsolicitud';
	}

/**
 * admin_add method
 *
 * @return void
 */
	public function admin_add() {
		if ($this->request->is('post')) {
			$this->Mensaje->create();
			if ($this->Mensaje->save($this->request->data)) {
				$this->Session->setFlash(__('The mensaje has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The mensaje could not be saved. Please, try again.'));
			}
		}
		$tipos = $this->Mensaje->Tipo->find('list');
		$categorias = $this->Mensaje->Categorium->find('list');
		$zonas = $this->Mensaje->Zona->find('list');
		$ciudads = $this->Mensaje->Ciudad->find('list');
		$this->set(compact('tipos', 'categorias', 'zonas', 'ciudads'));
	}

/**
 * admin_edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_edit($id = null) {
		if (!$this->Mensaje->exists($id)) {
			throw new NotFoundException(__('Invalid mensaje'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->Mensaje->save($this->request->data)) {
				$this->Session->setFlash(__('The mensaje has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The mensaje could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('Mensaje.' . $this->Mensaje->primaryKey => $id));
			$this->request->data = $this->Mensaje->find('first', $options);
		}
		$tipos = $this->Mensaje->Tipo->find('list');
		$categorias = $this->Mensaje->Categorium->find('list');
		$zonas = $this->Mensaje->Zona->find('list');
		$ciudads = $this->Mensaje->Ciudad->find('list');
		$this->set(compact('tipos', 'categorias', 'zonas', 'ciudads'));
	}

/**
 * admin_delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_delete($id = null) {
		$this->Mensaje->id = $id;
		if (!$this->Mensaje->exists()) {
			throw new NotFoundException(__('Invalid mensaje'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->Mensaje->delete()) {
			$this->Session->setFlash(__('The mensaje has been deleted.'));
		} else {
			$this->Session->setFlash(__('The mensaje could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}
	
	function solicitud()
	{if (!empty($this->data)) {
			/*Email para ITAI*/
			$ti=$this->data['Mensaje']['titulo'];
			$no=$this->data['Mensaje']['nombre'];
			$em=$this->data['Mensaje']['email'];
			$te=$this->data['Mensaje']['telefono'];
			$ce=$this->data['Mensaje']['celular'];
			$me=$this->data['Mensaje']['mensaje'];
			
			$tt=$this->daTipo($this->data['Mensaje']['tipo_id']);
			$cc=$this->daCategoria($this->data['Mensaje']['categoria_id']);
			$zz=$this->daZona($this->data['Mensaje']['zona_id']);
			$ttt=$tt['0']['tipos']['nombre'];
			$ccc=$cc['0']['categorias']['nombre'];
			$zzz=$zz['0']['zonas']['nombre'];
			
			$mensaj="
			SOLICTUDES DE INMUEBLE ITAI \n
			Titulo: $ti \n
			Nombre: $no \n
			Necesita: $ttt \n 
			En la Zona: $zzz \n 
			Para: $ccc \n 			
			Email:  $em \n
			Telefonos: $te \n
			Celular: $ce \n
			Mensaje: $me \n						
			";
			 $mensaj;			
			$from=$em;
			
			$cc=$this->daEmpresa(6); //obtiene el correo a mandar el cual puede ser cambiano en el admin
			$for=trim($cc['0']['empresas']['mensaje']);	
			$tema="SOLICITUDES - ITAI";
			
			mail($for,$tema,$mensaj,$from);
			/*EMAIL PARA ITAI*/			
			
			$this->Mensaje->create();
			if ($this->Mensaje->save($this->data)) {
				$this->Session->setFlash(__('The Mensaje has been saved', true));
				$this->redirect(array('action'=>'fin'));
			} else {
				$this->Session->setFlash(__('The Mensaje could not be saved. Please, try again.', true));
			}
		}
		$tipos = $this->Mensaje->Tipo->find('list');
		$categorias = $this->Mensaje->Categoria->find('list');
		$zonas = $this->Mensaje->Zona->find('list');
		$ciudads = $this->Mensaje->Ciudad->find('list');
		$this->set(compact('tipos', 'categorias', 'zonas', 'ciudads')); 

		
		
        parent::combos();
		
	}
	function fin()
	{   //parent::galeria(); 	
		parent::combos();
		
	}
	function admin_busqueda()
	{	
	if(isset($this->data['Mensaje']['busqueda'])){
	 $this->set('mensajes', $this->Mensaje->busqueda($this, $this->data['Mensaje']['busqueda']));
	 }else
	 {
	 $this->set('mensajes',$this->Mensaje->buscar($this,$this->data['tipo_id'],$this->data['categoria_id'],$this->data['ciudad_id'],$this->data['zona_id']));
	 }
	 parent::combos();
		$this->layout='admin';		
   }
   
   function captcha_image() 
    { $this->Captcha->image(); 

    }  

    function captcha_audio() 
    { 
    $this->Captcha->audio(); 
    } 
	 function daTipo($id=null)
	 {  $clientes=new User();
	 	$v=$clientes->query("Select * FROM tipos WHERE id='$id'");
	 	return $v; //devueleve array
	 }
	 function daZona($id=null)
	 {	$clientes=new User();
	 	 $v=$clientes->query("Select * FROM zonas WHERE id='$id'");
	 	return $v; //devueleve array
	 }
	 
	 function daCategoria($id=null)
	{	$cli=new User();
		$v=$cli->query("Select * FROM categorias WHERE id='$id'");
	 	return $v; //devueleve array			
	}
	function daEmpresa($id=null)
	{ $m=new User();
	  $v=$m->query("SELECT * FROM empresas WHERE id='$id'");
	  return $v;
		
	}
	
	function beforeFilter(){
		
        $this->Auth->allow('solicitud','fin','captcha_image'); 
		parent::beforeFilter();
    }
}
