<?php
App::uses('AppController', 'Controller');
/**
 * Zonas Controller
 *
 * @property Zona $Zona
 * @property PaginatorComponent $Paginator
 */
class ZonasController extends AppController {

/**
 * Components
 *
 * @var array
 */
	public $components = array('Paginator');

/**
 * index method
 *
 * @return void
 */
	public function index() {
		$this->Zona->recursive = 0;
		$this->set('zonas', $this->Paginator->paginate());
	}

/**
 * view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function view($id = null) {
		if (!$this->Zona->exists($id)) {
			throw new NotFoundException(__('Invalid zona'));
		}
		$options = array('conditions' => array('Zona.' . $this->Zona->primaryKey => $id));
		$this->set('zona', $this->Zona->find('first', $options));
	}

/**
 * add method
 *
 * @return void
 */
	public function add() {
		if ($this->request->is('post')) {
			$this->Zona->create();
			if ($this->Zona->save($this->request->data)) {
				$this->Session->setFlash(__('The zona has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The zona could not be saved. Please, try again.'));
			}
		}
		$ciudads = $this->Zona->Ciudad->find('list');
		$this->set(compact('ciudads'));
	}

/**
 * edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function edit($id = null) {
		if (!$this->Zona->exists($id)) {
			throw new NotFoundException(__('Invalid zona'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->Zona->save($this->request->data)) {
				$this->Session->setFlash(__('The zona has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The zona could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('Zona.' . $this->Zona->primaryKey => $id));
			$this->request->data = $this->Zona->find('first', $options);
		}
		$ciudads = $this->Zona->Ciudad->find('list');
		$this->set(compact('ciudads'));
	}

/**
 * delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function delete($id = null) {
		$this->Zona->id = $id;
		if (!$this->Zona->exists()) {
			throw new NotFoundException(__('Invalid zona'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->Zona->delete()) {
			$this->Session->setFlash(__('The zona has been deleted.'));
		} else {
			$this->Session->setFlash(__('The zona could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}

/**
 * admin_index method
 *
 * @return void
 */
	public function admin_index() {
		$this->Zona->recursive = 0;
		$this->set('zonas', $this->Paginator->paginate());
		//$this->layout='admin';
		$this->layout='bootzonas';
	}

/**
 * admin_view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_view($id = null) {
		if (!$this->Zona->exists($id)) {
			throw new NotFoundException(__('Invalid zona'));
		}
		$options = array('conditions' => array('Zona.' . $this->Zona->primaryKey => $id));
		$this->set('zona', $this->Zona->find('first', $options));
		$this->layout='bootzonas';
	}

/**
 * admin_add method
 *
 * @return void
 */
	public function admin_add() {
		if ($this->request->is('post')) {
			$this->Zona->create();
			if ($this->Zona->save($this->request->data)) {
				$this->Session->setFlash(__('The zona has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The zona could not be saved. Please, try again.'));
			}
		}
		$ciudads = $this->Zona->Ciudad->find('list');
		$this->set(compact('ciudads'));
		//$this->layout='admin';
		$this->layout='bootzonasadd';
	}

/**
 * admin_edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_edit($id = null) {
		if (!$this->Zona->exists($id)) {
			throw new NotFoundException(__('Invalid zona'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->Zona->save($this->request->data)) {
				$this->Session->setFlash(__('The zona has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The zona could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('Zona.' . $this->Zona->primaryKey => $id));
			$this->request->data = $this->Zona->find('first', $options);
		}
		$ciudads = $this->Zona->Ciudad->find('list');
		$this->set(compact('ciudads'));
		$this->layout='bootzonas';
	}

/**
 * admin_delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_delete($id = null) {
		$this->Zona->id = $id;
		if (!$this->Zona->exists()) {
			throw new NotFoundException(__('Invalid zona'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->Zona->delete()) {
			$this->Session->setFlash(__('The zona has been deleted.'));
		} else {
			$this->Session->setFlash(__('The zona could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}
}
