<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "formulario".
 *
 * @property integer $IdFormulario
 * @property string $NombreProyecto
 * @property integer $IdcTipoProyecto
 * @property integer $IdEmpresa
 * @property string $SuperficieTerreno
 * @property string $SuperficieTotalConstruida
 * @property string $CostoTotalProyecto
 * @property string $FinanciamientoRequerido
 * @property string $Notas
 * @property string $Latitud
 * @property string $Longitud
 * @property integer $IdCreadoPor
 * @property string $FechaCreacion
 * @property integer $IdModificadoPor
 * @property string $FechaModificacion
 *
 * @property Clasificadorcomun $idcTipoProyecto
 * @property User $idCreadoPor
 * @property Empresa $idEmpresa
 * @property User $idModificadoPor
 */
class Formulario extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'formulario';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['NombreProyecto', 'IdcTipoProyecto', 'IdEmpresa'], 'required'],
            [['IdcTipoProyecto', 'IdEmpresa', 'IdCreadoPor', 'IdModificadoPor'], 'integer'],
            [['SuperficieTerreno', 'SuperficieTotalConstruida', 'CostoTotalProyecto', 'Latitud', 'Longitud'], 'number'],
            [['Notas'], 'string'],
            [['FechaCreacion', 'FechaModificacion'], 'safe'],
            [['NombreProyecto'], 'string', 'max' => 250],
            [['FinanciamientoRequerido'], 'string', 'max' => 45],
            [['IdcTipoProyecto'], 'exist', 'skipOnError' => true, 'targetClass' => Clasificadorcomun::className(), 'targetAttribute' => ['IdcTipoProyecto' => 'IdClasificadorComun']],
            [['IdCreadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdCreadoPor' => 'id']],
            [['IdEmpresa'], 'exist', 'skipOnError' => true, 'targetClass' => Empresa::className(), 'targetAttribute' => ['IdEmpresa' => 'IdEmpresa']],
            [['IdModificadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdModificadoPor' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'IdFormulario' => 'Id Formulario',
            'NombreProyecto' => 'Nombre Proyecto',
            'IdcTipoProyecto' => 'Idc Tipo Proyecto',
            'IdEmpresa' => 'Id Empresa',
            'SuperficieTerreno' => 'Superficie Terreno',
            'SuperficieTotalConstruida' => 'Superficie Total Construida',
            'CostoTotalProyecto' => 'Costo Total Proyecto',
            'FinanciamientoRequerido' => 'Financiamiento Requerido',
            'Notas' => 'Notas',
            'Latitud' => 'Latitud',
            'Longitud' => 'Longitud',
            'IdCreadoPor' => 'Id Creado Por',
            'FechaCreacion' => 'Fecha Creacion',
            'IdModificadoPor' => 'Id Modificado Por',
            'FechaModificacion' => 'Fecha Modificacion',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdcTipoProyecto()
    {
        return $this->hasOne(Clasificadorcomun::className(), ['IdClasificadorComun' => 'IdcTipoProyecto']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdCreadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdCreadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdEmpresa()
    {
        return $this->hasOne(Empresa::className(), ['IdEmpresa' => 'IdEmpresa']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdModificadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdModificadoPor']);
    }
}
