<?php

namespace app\models;

use Yii;
use yii\base\Model;

/**
 * PasswordForm is the model behind the password form.
 */
class PasswordForm extends Model
{
    public $oldPassword;
    public $newPassword;
    public $newPassword2;

    private $_user = false;
    /**
     * @return array the validation rules.
     */
    public function rules()
    {
        return [
            [['oldPassword', 'newPassword', 'newPassword2'], 'required'],
            // password is validated by validatePassword()
            ['oldPassword', 'validatePassword'],
            [['newPassword2'], 'compare', 'compareAttribute' => 'newPassword', 'operator'=>'=='],
            [['newPassword'], 'compare', 'compareAttribute' => 'oldPassword', 'operator'=>'!=']
        ];
    }

    /**
     * Validates the password.
     * This method serves as the inline validation for password.
     *
     * @param string $attribute the attribute currently being validated
     * @param array $params the additional name-value pairs given in the rule
     */
    public function validatePassword($attribute, $params)
    {
        if (!$this->hasErrors()) {
            $user = $this->getUser();

            if (!$user || !$user->validatePassword($this->oldPassword)) {
                $this->addError($attribute, 'Contraseña incorrecta');
            }
        }
    }

    /**
     * Logs in a user using the provided username and password.
     * @return boolean whether the user is logged in successfully
     */
    public function passwordChange()
    {
        if ($this->validate()) {
            $user = $this->getUser();
            if ($user){
                $user->setPassword( $this->newPassword );
                $user->save();

                return true;
            }
        }
        return false;
    }

    /**
     * Finds user by [[username]]
     *
     * @return User|null
     */
    public function getUser()
    {
        if ($this->_user === false) {
            $this->_user = User::findByUsername(Yii::$app->user->identity->username);
        }

        return $this->_user;
    }

    /**
     * Returns the attribute labels.
     *
     * See Model class for more details
     *
     * @return array attribute labels (name => label).
     */
    public function attributeLabels()
    {
        return [
            'oldPassword' => 'Contraseña actual',
            'newPassword' => 'Nueva contraseña',
            'newPassword2' => 'Repita nueva contraseña'
        ];
    }
}
