<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "user".
 *
 * @property integer $id
 * @property integer $IdPersona
 * @property string $username
 * @property string $auth_key
 * @property string $password_hash
 * @property string $password_reset_token
 * @property string $access_token
 * @property integer $IdCreadoPor
 * @property string $FechaCreacion
 * @property integer $IdModificadoPor
 * @property string $FechaModificacion
 * @property string $Rol
 * @property boolean $Activo
 *
 * @property Capa[] $capas
 * @property Capa[] $capas0
 * @property Imagen[] $imagens
 * @property Persona[] $personas
 * @property Persona[] $personas0
 * @property Proyecto[] $proyectos
 * @property Proyecto[] $proyectos0
 * @property Persona $idPersona
 * @property User $idCreadoPor
 * @property User[] $users
 * @property User $idModificadoPor
 * @property User[] $users0
 */
class User extends \yii\db\ActiveRecord  implements \yii\web\IdentityInterface
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'user';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['IdPersona', 'IdCreadoPor', 'IdModificadoPor'], 'integer'],
            [['FechaCreacion', 'FechaModificacion'], 'safe'],
            [['Activo'], 'boolean'],
            [['username', 'password_hash', 'password_reset_token', 'access_token'], 'string', 'max' => 255],
            [['auth_key'], 'string', 'max' => 32],
            [['Rol'], 'string', 'max' => 25],
            [['IdPersona'], 'exist', 'skipOnError' => true, 'targetClass' => Persona::className(), 'targetAttribute' => ['IdPersona' => 'IdPersona']],
            [['IdCreadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdCreadoPor' => 'id']],
            [['IdModificadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdModificadoPor' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'IdPersona' => 'Id Persona',
            'username' => 'Username',
            'auth_key' => 'Auth Key',
            'password_hash' => 'Password Hash',
            'password_reset_token' => 'Password Reset Token',
            'access_token' => 'Access Token',
            'IdCreadoPor' => 'Id Creado Por',
            'FechaCreacion' => 'Fecha Creacion',
            'IdModificadoPor' => 'Id Modificado Por',
            'FechaModificacion' => 'Fecha Modificacion',
            'Rol' => 'Rol',
            'Activo' => 'Activo',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCapas()
    {
        return $this->hasMany(Capa::className(), ['IdCreadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCapas0()
    {
        return $this->hasMany(Capa::className(), ['IdModificadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getImagens()
    {
        return $this->hasMany(Imagen::className(), ['CreadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPersonas()
    {
        return $this->hasMany(Persona::className(), ['IdCreadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPersonas0()
    {
        return $this->hasMany(Persona::className(), ['IdModificadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProyectos()
    {
        return $this->hasMany(Proyecto::className(), ['IdCreadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProyectos0()
    {
        return $this->hasMany(Proyecto::className(), ['IdModificadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdPersona()
    {
        return $this->hasOne(Persona::className(), ['IdPersona' => 'IdPersona']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdCreadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdCreadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUsers()
    {
        return $this->hasMany(User::className(), ['IdCreadoPor' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdModificadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdModificadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUsers0()
    {
        return $this->hasMany(User::className(), ['IdModificadoPor' => 'id']);
    }














    /////////////////////////////

    public  static  function findByUsername( $username ){
        return static::findOne(['username'=>$username]);
    }

    /**
     * Finds an identity by the given ID.
     * @param string|integer $id the ID to be looked for
     * @return IdentityInterface the identity object that matches the given ID.
     * Null should be returned if such an identity cannot be found
     * or the identity is not in an active state (disabled, deleted, etc.)
     */
    public static function findIdentity($id)
    {
        // TODO: Implement findIdentity() method.
        return self::findOne($id);
    }

    /**
     * Finds an identity by the given token.
     * @param mixed $token the token to be looked for
     * @param mixed $type the type of the token. The value of this parameter depends on the implementation.
     * For example, [[\yii\filters\auth\HttpBearerAuth]] will set this parameter to be `yii\filters\auth\HttpBearerAuth`.
     * @return IdentityInterface the identity object that matches the given token.
     * Null should be returned if such an identity cannot be found
     * or the identity is not in an active state (disabled, deleted, etc.)
     */
    public static function findIdentityByAccessToken($token, $type = null)
    {
        // TODO: Implement findIdentityByAccessToken() method.

        return static::findOne( ['access_token'=>$token ] );
        //return null;
    }

    /**
     * Returns an ID that can uniquely identify a user identity.
     * @return string|integer an ID that uniquely identifies a user identity.
     */
    public function getId()
    {
        // TODO: Implement getId() method.
        return $this->id;
    }

    /**
     * Returns a key that can be used to check the validity of a given identity ID.
     *
     * The key should be unique for each individual user, and should be persistent
     * so that it can be used to check the validity of the user identity.
     *
     * The space of such keys should be big enough to defeat potential identity attacks.
     *
     * This is required if [[User::enableAutoLogin]] is enabled.
     * @return string a key that is used to check the validity of a given identity ID.
     * @see validateAuthKey()
     */
    public function getAuthKey()
    {
        // TODO: Implement getAuthKey() method.
        return $this->auth_key;
    }

    /**
     * Validates the given auth key.
     *
     * This is required if [[User::enableAutoLogin]] is enabled.
     * @param string $authKey the given auth key
     * @return boolean whether the given auth key is valid.
     * @see getAuthKey()
     */
    public function validateAuthKey($authKey)
    {
        // TODO: Implement validateAuthKey() method.
        return $this->auth_key = $authKey;
    }
    /**
     * Generates "remember me" authentication key
     */
    public function generateAuthKey()
    {
        $this->auth_key = Yii::$app->security->generateRandomString();
    }
    //////::::::::
    /**
     * Generates password hash from password and sets it to the model
     *
     * @param string $password
     */
    public function setPassword($password){

        $this->password_hash = Yii::$app->security->generatePasswordHash($password);
    }


    /**
     * Validates password
     *
     * @param string $password password to validate
     * @return boolean if password provided is valid for current user
     */
    public function validatePassword($password)
    {
        //return $this->password === sha1($password);
        return Yii::$app->security->validatePassword($password, $this->password_hash  );
    }


    /**   Set auth_key  beforeSave  */
    public function beforeSave($insert)
    {
        if (parent::beforeSave($insert)) {
            if ($this->isNewRecord) {
                $this->auth_key = \Yii::$app->security->generateRandomString();
            }
            return true;
        }
        return false;
    }






}
