<?php

/* @var $this \yii\web\View */
/* @var $content string */

use app\commands\Roles;
use yii\helpers\Html;
use yii\bootstrap\Nav;
use yii\bootstrap\NavBar;
use yii\widgets\Breadcrumbs;
use app\assets\AppAsset;

AppAsset::register($this);
?>
<?php $this->beginPage() ?>
<!DOCTYPE html>
<html lang="<?= Yii::$app->language ?>">
<head>
    <meta charset="<?= Yii::$app->charset ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="favicon.ico" rel="shortcut icon" type="image/x-icon" />
    <?= Html::csrfMetaTags() ?>
    <title><?= Html::encode($this->title) ?></title>
    <?php $this->head() ?>
</head>
<body>
<?php $this->beginBody() ?>

<div class="wrap">
    <?php
    NavBar::begin([

        'brandLabel' => Html::img('images/icon.png',["width"=>"43px", "class"=>"pull-left"]) . '&nbsp; Inicio',
        'brandUrl' => Yii::$app->homeUrl,
        'options' => [
            'class' => 'navbar-inverse navbar-fixed-top',
        ],
    ]);
    if(Yii::$app->user->isGuest) {
        echo Nav::widget([
                'options' => ['class' => 'navbar-nav navbar-right'],
                'items' => [
                        ['label' => 'Login', 'url' => ['/site/login']],
                        ['label' => 'Acerca de', 'url' => ['/site/about']]
                ],
        ]);
    }
    else {

        if(Yii::$app->user->identity->Rol==Roles::Administrador) {
            echo Nav::widget([
                    'options' => ['class' => 'navbar-nav navbar-right small'],
                    'items' => [
                            ['label' => 'Dashboard', 'url' => ['/dashboard/index']],
                            ['label' => 'Proyectos', 'url' => ['/proyecto/index']],
                            ['label' => 'Importación', 'items' => [
                                    ['label' => 'Polígonos KMZs', 'url' => ['/importacion/kmz']],
                                    ['label' => 'Capas estáticas', 'url' => ['/capa/index']],
                            ]],
                            ['label' => 'Configuración', 'items' => [
                                    ['label' => 'Personas', 'url' => ['/persona/index']],
                                    ['label' => 'Usuarios', 'url' => ['/user/index']],
                                    ['label' => 'Clasificadores', 'url' => ['/clasificadorcomun/index']],
                            ]],
                            '<li>'
                            .
                            Html::a(Yii::$app->user->identity->username, ['/site/password'], ['class' => 'btn btn-link glyphicon glyphicon-user', 'title' => 'Cambiar Contraseña'])
                            . '</li>'
                            ,
                            '<li>'
                            . Html::beginForm(['/site/logout'], 'post', ['class' => 'navbar-form', 'style' => 'text-align: center'])
                            . Html::submitButton(
                                    '',
                                    ['class' => 'btn btn-link glyphicon glyphicon-log-out', 'title' => 'Salir del sistema('. Yii::$app->user->identity->username . ')']
                            )
                            . Html::endForm()
                            . '</li>'
                            ,
                            '<li>'
                            .
                            Html::a('', ['/site/about'], ['class' => 'btn btn-link glyphicon glyphicon-question-sign', 'title' => 'Acerca del Sistema'])
                            . '</li>'

                    ],
            ]);
        }
        else if(Yii::$app->user->identity->Rol==Roles::Registrador) {
            echo Nav::widget([
                    'options' => ['class' => 'navbar-nav navbar-right'],
                    'items' => [
                            ['label' => 'Dashboard', 'url' => ['/dashboard/index']],
                            ['label' => 'Proyectos', 'url' => ['/proyecto/index']],
                            '<li>'
                            .
                            Html::a(Yii::$app->user->identity->username, ['/site/password'], ['class' => 'btn btn-link glyphicon glyphicon-user', 'title' => 'Cambiar Contraseña'])
                            . '</li>'
                        ,
                            '<li>'
                            . Html::beginForm(['/site/logout'], 'post', ['class' => 'navbar-form', 'style' => 'text-align: center'])
                            . Html::submitButton(
                                    '',
                                    ['class' => 'btn btn-link glyphicon glyphicon-log-out', 'title' => 'Salir del sistema('. Yii::$app->user->identity->username . ')']
                            )
                            . Html::endForm()
                            . '</li>'
                        ,
                            '<li>'
                            .
                            Html::a('', ['/site/about'], ['class' => 'btn btn-link glyphicon glyphicon-question-sign', 'title' => 'Acerca del Sistema'])
                            . '</li>'
                    ],
            ]);
        }
        else if(Yii::$app->user->identity->Rol==Roles::Gerencia) {
            echo Nav::widget([
                    'options' => ['class' => 'navbar-nav navbar-right'],
                    'items' => [
                            ['label' => 'Dashboard', 'url' => ['/dashboard/index']],
                            '<li>'
                            .
                            Html::a(Yii::$app->user->identity->username, ['/site/password'], ['class' => 'btn btn-link glyphicon glyphicon-user', 'title' => 'Cambiar Contraseña'])
                            . '</li>'
                        ,
                            '<li>'
                            . Html::beginForm(['/site/logout'], 'post', ['class' => 'navbar-form', 'style' => 'text-align: center'])
                            . Html::submitButton(
                                    '',
                                    ['class' => 'btn btn-link glyphicon glyphicon-log-out', 'title' => 'Salir del sistema('. Yii::$app->user->identity->username . ')']
                            )
                            . Html::endForm()
                            . '</li>'
                        ,
                            '<li>'
                            .
                            Html::a('', ['/site/about'], ['class' => 'btn btn-link glyphicon glyphicon-question-sign', 'title' => 'Acerca del Sistema'])
                            . '</li>'

                    ],
            ]);
        }
    }
    NavBar::end();
    ?>

    <div class="container">
        <?= Breadcrumbs::widget([
            'links' => isset($this->params['breadcrumbs']) ? $this->params['breadcrumbs'] : [],
        ]) ?>
        <?= $content ?>
    </div>
</div>

<footer class="footer">
    <div class="container">
        <div class="row">
            <div class="col-xs-8 col-xs-offset-3 col-sm-4 col-sm-offset-0 col-lg-4 ">
                &copy; FIBRA FIC <?= date('Y') ?>
            </div>
            <div  class="hidden-xs col-sm-4  col-sm-offset-0  col-lg-5  "    ></div>
            <div class="col-xs-8 col-xs-offset-3  col-sm-4  col-sm-offset-0  col-lg-3  ">
                 <table><tr><td><strong>Powered by :</strong> &nbsp; </td><td><a href="http://www.dreamers-soft.com"><?=Html::img('images/logo-dreamers.png',["width"=>"100px", "class"=>"pull-right"])?></a></td></tr></table>
            </div>

        </div>
    </div>

</footer>

<?php $this->endBody() ?>
</body>
</html>
<?php $this->endPage() ?>
